# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import commondata_pb2 as commondata__pb2


class DBInterfaceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.query_db = channel.unary_unary(
                '/DBInterface/query_db',
                request_serializer=commondata__pb2.query_params.SerializeToString,
                response_deserializer=commondata__pb2.data_ret.FromString,
                )


class DBInterfaceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def query_db(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DBInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'query_db': grpc.unary_unary_rpc_method_handler(
                    servicer.query_db,
                    request_deserializer=commondata__pb2.query_params.FromString,
                    response_serializer=commondata__pb2.data_ret.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'DBInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DBInterface(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def query_db(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DBInterface/query_db',
            commondata__pb2.query_params.SerializeToString,
            commondata__pb2.data_ret.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)


class FuncInterfaceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.run_func = channel.unary_unary(
                '/FuncInterface/run_func',
                request_serializer=commondata__pb2.func_params.SerializeToString,
                response_deserializer=commondata__pb2.func_ret.FromString,
                )


class FuncInterfaceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def run_func(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FuncInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'run_func': grpc.unary_unary_rpc_method_handler(
                    servicer.run_func,
                    request_deserializer=commondata__pb2.func_params.FromString,
                    response_serializer=commondata__pb2.func_ret.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'FuncInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FuncInterface(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def run_func(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/FuncInterface/run_func',
            commondata__pb2.func_params.SerializeToString,
            commondata__pb2.func_ret.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)



import grpc

from django.conf import settings


class Client:

    conn = None

    @classmethod
    def connect(cls, server):
        """
        # 连接 rpc 服务器
        :param server:
        :return:
        """

        cls.conn = grpc.insecure_channel(server)

    @classmethod
    def get_conn(cls):
        return cls.conn


server = settings.COMMON_DATA_SERVER

Client.connect(server)


import sys
from .apis import run_func

def get_nic(c, m="name"):
    """
    根据编码获取行业全名
    :param c:
    :param m:
    :return:
    """

    status, ret = run_func(c, m=m, func=sys._getframe().f_code.co_name)
    return ret




import json

from . import commondata_pb2, commondata_pb2_grpc
from .client import Client

con = Client.get_conn()

# 调用 rpc 服务
db_interface_stub = commondata_pb2_grpc.DBInterfaceStub(con)

def do_query(query_obj):
    """
    :param query_json:
    :return: status, data
    """
    query_json = json.dumps(query_obj)
    ret = db_interface_stub.query_db(commondata_pb2.query_params(params=query_json))
    ret_data = json.loads(ret.data)

    status = ret_data['status']
    data = json.loads(ret_data['data_json'])
   
    return status, data


func_interface_stub = commondata_pb2_grpc.FuncInterfaceStub(con)

def run_func(*args, **kwargs):

    params = {'args': args, 'kwargs': kwargs}
    params_json = json.dumps(params)

    ret = func_interface_stub.run_func(commondata_pb2.func_params(params=params_json))
    ret_data = json.loads(ret.data)

    status = ret_data['status']
    data = json.loads(ret_data['data_json'])

    return status, data


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: commondata.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='commondata.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10\x63ommondata.proto\"\x1e\n\x0cquery_params\x12\x0e\n\x06params\x18\x01 \x01(\t\"\x18\n\x08\x64\x61ta_ret\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"\x1d\n\x0b\x66unc_params\x12\x0e\n\x06params\x18\x01 \x01(\t\"\x18\n\x08\x66unc_ret\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t25\n\x0b\x44\x42Interface\x12&\n\x08query_db\x12\r.query_params\x1a\t.data_ret\"\x00\x32\x36\n\rFuncInterface\x12%\n\x08run_func\x12\x0c.func_params\x1a\t.func_ret\"\x00\x62\x06proto3'
)




_QUERY_PARAMS = _descriptor.Descriptor(
  name='query_params',
  full_name='query_params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='query_params.params', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20,
  serialized_end=50,
)


_DATA_RET = _descriptor.Descriptor(
  name='data_ret',
  full_name='data_ret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='data_ret.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=76,
)


_FUNC_PARAMS = _descriptor.Descriptor(
  name='func_params',
  full_name='func_params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='func_params.params', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=107,
)


_FUNC_RET = _descriptor.Descriptor(
  name='func_ret',
  full_name='func_ret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='func_ret.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=133,
)

DESCRIPTOR.message_types_by_name['query_params'] = _QUERY_PARAMS
DESCRIPTOR.message_types_by_name['data_ret'] = _DATA_RET
DESCRIPTOR.message_types_by_name['func_params'] = _FUNC_PARAMS
DESCRIPTOR.message_types_by_name['func_ret'] = _FUNC_RET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

query_params = _reflection.GeneratedProtocolMessageType('query_params', (_message.Message,), {
  'DESCRIPTOR' : _QUERY_PARAMS,
  '__module__' : 'commondata_pb2'
  # @@protoc_insertion_point(class_scope:query_params)
  })
_sym_db.RegisterMessage(query_params)

data_ret = _reflection.GeneratedProtocolMessageType('data_ret', (_message.Message,), {
  'DESCRIPTOR' : _DATA_RET,
  '__module__' : 'commondata_pb2'
  # @@protoc_insertion_point(class_scope:data_ret)
  })
_sym_db.RegisterMessage(data_ret)

func_params = _reflection.GeneratedProtocolMessageType('func_params', (_message.Message,), {
  'DESCRIPTOR' : _FUNC_PARAMS,
  '__module__' : 'commondata_pb2'
  # @@protoc_insertion_point(class_scope:func_params)
  })
_sym_db.RegisterMessage(func_params)

func_ret = _reflection.GeneratedProtocolMessageType('func_ret', (_message.Message,), {
  'DESCRIPTOR' : _FUNC_RET,
  '__module__' : 'commondata_pb2'
  # @@protoc_insertion_point(class_scope:func_ret)
  })
_sym_db.RegisterMessage(func_ret)



_DBINTERFACE = _descriptor.ServiceDescriptor(
  name='DBInterface',
  full_name='DBInterface',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=135,
  serialized_end=188,
  methods=[
  _descriptor.MethodDescriptor(
    name='query_db',
    full_name='DBInterface.query_db',
    index=0,
    containing_service=None,
    input_type=_QUERY_PARAMS,
    output_type=_DATA_RET,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DBINTERFACE)

DESCRIPTOR.services_by_name['DBInterface'] = _DBINTERFACE


_FUNCINTERFACE = _descriptor.ServiceDescriptor(
  name='FuncInterface',
  full_name='FuncInterface',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=190,
  serialized_end=244,
  methods=[
  _descriptor.MethodDescriptor(
    name='run_func',
    full_name='FuncInterface.run_func',
    index=0,
    containing_service=None,
    input_type=_FUNC_PARAMS,
    output_type=_FUNC_RET,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FUNCINTERFACE)

DESCRIPTOR.services_by_name['FuncInterface'] = _FUNCINTERFACE

# @@protoc_insertion_point(module_scope)
